@@ -25,37 +25,20 @@ extern crate libc;
 mod ll;
 mod encoder;
 mod decoder;
+pub mod dict;
 
 pub use encoder::Encoder;
 pub use decoder::Decoder;
 
-use std::io;
-
-/// Trains a dictionary to improve compression of small files.
-///
-/// The dictionary must be present during decompression,
-/// but can be shared accross multiple "similar" files.
-pub fn train_dict(sample_data: &[u8], sample_sizes: &[usize], max_size: usize) -> io::Result<Vec<u8>> {
-    let mut result = Vec::with_capacity(max_size);
-    unsafe {
-        let code = ll::ZDICT_trainFromBuffer(result.as_mut_ptr(),
-                                             result.capacity(),
-                                             sample_data.as_ptr(),
-                                             sample_sizes.as_ptr(),
-                                             sample_sizes.len());
-        let written = try!(ll::parse_code(code));
-        result.set_len(written);
-    }
-    Ok(result)
-}
-
 #[test]
 fn test_cycle() {
     use std::io::{Read, Write};
-    let text = "This is a sample text. It is not meant to be interesting or anything. Just text, \
-                nothing more. Don't expect too much from it.";
+    let text = "This is a sample text. \
+                It is not meant to be interesting or anything. \
+                Just text, nothing more. \
+                Don't expect too much from it.";
 
-    let mut buffer: Vec<u8> = Vec::new();
+    let buffer: Vec<u8> = Vec::new();
 
     let mut encoder = Encoder::new(buffer, 1).unwrap();
     encoder.write_all(text.as_bytes()).unwrap();
